@@ -43,7 +43,7 @@ $text = ($this->task == 'edit'
 	? Lang::txt('JACTION_EDIT') . ' #' . $this->model->get('id') . ' (v.' . $this->model->get('version_label') . ')'
 	: Lang::txt('JACTION_CREATE'));
 
-Toolbar::title(Lang::txt('COM_PUBLICATIONS_PUBLICATION') . ': ' . $text, 'addedit.png');
+Toolbar::title(Lang::txt('COM_PUBLICATIONS_PUBLICATION') . ': ' . $text, 'publications');
 if ($canDo->get('core.edit'))
 {
 	Toolbar::apply();
@@ -72,7 +72,7 @@ $customFields = $rt->customFields && $rt->customFields != '{"fields":[]}' ? $rt-
 
 $customFields = $this->model->_curationModel->getMetaSchema();
 
-include_once(PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'models' . DS . 'elements.php');
+include_once Component::path('com_publications') . DS . 'models' . DS . 'elements.php';
 
 $elements = new \Components\Publications\Models\Elements($data, $customFields);
 $fields   = $elements->render();
@@ -328,7 +328,8 @@ function popratings()
 						<tr>
 							<th><?php echo Lang::txt('COM_PUBLICATIONS_FIELD_VERSION'); ?></th>
 							<td>
-								<?php echo $this->model->get('version_label') . ' (' . $status . ')'; ?>
+								<input type="text" name="version_label" id="field-version_label" maxlength="250" size="10" value="<?php echo $this->escape($this->model->get('version_label')); ?>" />
+								<?php echo ' (' . $status . ')'; ?>
 							</td>
 						</tr>
 						<tr>
@@ -360,6 +361,13 @@ function popratings()
 						<option value="2"<?php echo ($this->model->get('state') == 2) ? ' selected="selected"' : ''; ?>><?php echo Lang::txt('COM_PUBLICATIONS_VERSION_DELETED'); ?></option>
 					</select>
 				</div>
+				<div class="input-wrap">
+					<label for="field-featured"><?php echo Lang::txt('COM_PUBLICATIONS_FIELD_FEATURED'); ?>:</label><br />
+					<select name="featured" id="field-featured">
+						<option value="0"<?php echo ($this->model->get('featured') == 0) ? ' selected="selected"' : ''; ?>><?php echo Lang::txt('COM_PUBLICATIONS_NO'); ?></option>
+						<option value="1"<?php echo ($this->model->get('featured') == 1) ? ' selected="selected"' : ''; ?>><?php echo Lang::txt('COM_PUBLICATIONS_YES'); ?></option>
+					</select>
+				</div>
 				<div class="input-wrap">
 					<label for="access"><?php echo Lang::txt('COM_PUBLICATIONS_FIELD_ACCESS'); ?>:</label>
 					<?php
